@@ -5,7 +5,5 @@ from . import views
 urlpatterns = [
     path('', views.blog, name='blog'),
     path('rss/', LatestPostsFeed(), name="post_feed"),
-    path('<slug:slug>/', views.view_post, name='post'),
-
-
+    path('<slug:slug>/', views.view_post, name='view_post'),
 ]
